==> okio-tvosx64-3.3.0-javadoc.jar: okio/okio/-buffered-sink/write.md <==
//[okio](../../../index.md)/[okio](../index.md)/[BufferedSink](index.md)/[write](write.md)

# write

[common, jvm, nonJvm]\
[common]\
expect abstract fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md)): [BufferedSink](index.md)

[jvm]\
actual abstract fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md)): [BufferedSink](index.md)

[nonJvm]\
actual abstract fun [write](write.md)(byteString: ByteString): [BufferedSink](index.md)

[common]\
expect abstract fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [BufferedSink](index.md)

[jvm]\
actual abstract fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [BufferedSink](index.md)

[nonJvm]\
actual abstract fun [write](write.md)(byteString: ByteString, offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [BufferedSink](index.md)

[jvm, nonJvm]\
actual abstract fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html)): [BufferedSink](index.md)

[jvm, nonJvm]\
actual abstract fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [BufferedSink](index.md)

[jvm]\
actual abstract fun [write](write.md)(source: [Source](../-source/index.md#1331753033%2FExtensions%2F1033915053), byteCount: [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)): [BufferedSink](index.md)

[nonJvm]\
actual abstract fun [write](write.md)(source: Source, byteCount: [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)): [BufferedSink](index.md)

[common]\
expect abstract fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html)): [BufferedSink](index.md)

Like OutputStream.write, this writes a complete byte array to this sink.

[common]\
expect abstract fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [BufferedSink](index.md)

Like OutputStream.write, this writes `byteCount` bytes of `source`, starting at `offset`.

[common]\
expect abstract fun [write](write.md)(source: [Source](../-source/index.md), byteCount: [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)): [BufferedSink](index.md)

Removes `byteCount` bytes from `source` and appends them to this sink.

==> okio-tvosx64-3.9.0-javadoc.jar: okio/okio/-buffered-sink/write.md <==
//[okio](../../../index.md)/[okio](../index.md)/[BufferedSink](index.md)/[write](write.md)

# write

[common, jvm, nonJvm]\
[common]\
expect abstract fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md)): [BufferedSink](index.md)

[jvm, nonJvm]\
actual abstract fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md)): [BufferedSink](index.md)

[common]\
expect abstract fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [BufferedSink](index.md)

[jvm, nonJvm]\
actual abstract fun [write](write.md)(byteString: [ByteString](../-byte-string/index.md), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [BufferedSink](index.md)

[jvm, nonJvm]\
actual abstract fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html)): [BufferedSink](index.md)

[jvm, nonJvm]\
actual abstract fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [BufferedSink](index.md)

[jvm]\
actual abstract fun [write](write.md)(source: [Source](../-source/index.md#1331753033%2FMain%2F1033915053), byteCount: [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)): [BufferedSink](index.md)

[nonJvm]\
actual abstract fun [write](write.md)(source: [Source](../-source/index.md), byteCount: [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)): [BufferedSink](index.md)

[common]\
expect abstract fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html)): [BufferedSink](index.md)

Like OutputStream.write, this writes a complete byte array to this sink.

[common]\
expect abstract fun [write](write.md)(source: [ByteArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-byte-array/index.html), offset: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), byteCount: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [BufferedSink](index.md)

Like OutputStream.write, this writes `byteCount` bytes of `source`, starting at `offset`.

[common]\
expect abstract fun [write](write.md)(source: [Source](../-source/index.md), byteCount: [Long](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-long/index.html)): [BufferedSink](index.md)

Removes `byteCount` bytes from `source` and appends them to this sink.
